searchData={"items":[{"type":"module","title":"GitHubActions","doc":"A little tool to write GitHub actions in Elixir.","ref":"GitHubActions.html"},{"type":"function","title":"GitHubActions.run/1","doc":"Creates a GitHub actions workflow file.","ref":"GitHubActions.html#run/1"},{"type":"module","title":"GitHubActions.Config","doc":"A simple keyword-based configuration API.","ref":"GitHubActions.Config.html"},{"type":"module","title":"Examples - GitHubActions.Config","doc":"This module is used to define the configuration for `GitHubActions`.\n\n```elixir\nimport GitHubActions.Config\n\nconfig :linux,\n  name: \"Ubuntu\",\n  runs_on: \"ubuntu-20.04\"\n\nconfig key: \"value\"\n```","ref":"GitHubActions.Config.html#module-examples"},{"type":"function","title":"GitHubActions.Config.config/0","doc":"Returns the configuration.","ref":"GitHubActions.Config.html#config/0"},{"type":"type","title":"GitHubActions.Config.config/0","doc":"","ref":"GitHubActions.Config.html#t:config/0"},{"type":"function","title":"GitHubActions.Config.config/1","doc":"Adds the given data to the configuration.\n\nReturns the configuration that was previously stored.","ref":"GitHubActions.Config.html#config/1"},{"type":"function","title":"GitHubActions.Config.config/2","doc":"Adds the given `value` to the configuration under the given `key`.\n\nReturns the configuration that was previously stored.","ref":"GitHubActions.Config.html#config/2"},{"type":"function","title":"GitHubActions.Config.fetch/1","doc":"Returns the value for `key` or `keys` in a tuple.\n\nIf the configuration parameter does not exist, the function returns `error`.","ref":"GitHubActions.Config.html#fetch/1"},{"type":"function","title":"Examples - GitHubActions.Config.fetch/1","doc":"iex> Config.fetch(:jobs)\n    {:ok, [:linux]}\n\n    iex> Config.fetch(:foo)\n    :error\n\n    iex> Config.fetch([:linux, :name])\n    {:ok, \"Ubuntu\"}","ref":"GitHubActions.Config.html#fetch/1-examples"},{"type":"function","title":"GitHubActions.Config.fetch!/1","doc":"Returns the value for `key` or `keys`.","ref":"GitHubActions.Config.html#fetch!/1"},{"type":"function","title":"Examples - GitHubActions.Config.fetch!/1","doc":"iex> Config.fetch!(:jobs)\n    [:linux]\n\n    iex> Config.fetch!([:linux, :runs_on])\n    \"ubuntu-20.04\"\n\n    iex> Config.fetch!([:linux, :foo])\n    ** (KeyError) key :foo not found in: [name: \"Ubuntu\", runs_on: \"ubuntu-20.04\"]","ref":"GitHubActions.Config.html#fetch!/1-examples"},{"type":"function","title":"GitHubActions.Config.get/2","doc":"Returns the value for `key` or `keys`.\n\nIf the configuration parameter does not exist, the function returns the\ndefault value.","ref":"GitHubActions.Config.html#get/2"},{"type":"function","title":"Examples - GitHubActions.Config.get/2","doc":"iex> Config.get(:jobs)\n    [:linux]\n\n    iex> Config.get(:foo, :bar)\n    :bar\n\n    iex> Config.get([:linux, :runs_on])\n    \"ubuntu-20.04\"\n\n    iex> Config.get(:foo)\n    nil","ref":"GitHubActions.Config.html#get/2-examples"},{"type":"type","title":"GitHubActions.Config.key/0","doc":"","ref":"GitHubActions.Config.html#t:key/0"},{"type":"type","title":"GitHubActions.Config.keys/0","doc":"","ref":"GitHubActions.Config.html#t:keys/0"},{"type":"function","title":"GitHubActions.Config.read/1","doc":"Reads the configuration from the given `path`.","ref":"GitHubActions.Config.html#read/1"},{"type":"type","title":"GitHubActions.Config.value/0","doc":"","ref":"GitHubActions.Config.html#t:value/0"},{"type":"module","title":"GitHubActions.Mix","doc":"Some functions for handling mix commands in workflows.","ref":"GitHubActions.Mix.html"},{"type":"function","title":"GitHubActions.Mix.mix/1","doc":"Generates a mix task.","ref":"GitHubActions.Mix.html#mix/1"},{"type":"function","title":"Examples - GitHubActions.Mix.mix/1","doc":"iex> mix(:compile)\n    \"mix compile\"","ref":"GitHubActions.Mix.html#mix/1-examples"},{"type":"function","title":"GitHubActions.Mix.mix/2","doc":"Generates a mix task with a sub task or options.\n\n  The options will be converted to command line options.\n\n  The \"special\" options `:env` and `:os` are used to set `MIX_ENV`.","ref":"GitHubActions.Mix.html#mix/2"},{"type":"function","title":"Examples - GitHubActions.Mix.mix/2","doc":"iex> mix(:deps, :compile)\n      \"mix deps.compile\"\n\n      iex> mix(:credo, strict: true)\n      \"mix credo --strict\"\n\n      iex> mix(:credo, strict: false)\n      \"mix credo\"\n\n      iex> mix(:sample, arg: 42)\n      \"mix sample --arg 42\"\n\n      iex> mix(:compile, env: :test)\n      \"MIX_ENV=test mix compile\"\n\n      iex> mix(:compile, env: :test, os: :windows)\n      \"set MIX_ENV=test\\nmix compile\\n\"\n\n      iex> mix(:compile, os: :windows)\n      \"mix compile\"","ref":"GitHubActions.Mix.html#mix/2-examples"},{"type":"function","title":"GitHubActions.Mix.mix/3","doc":"Generates a mix task with a sub task or options.","ref":"GitHubActions.Mix.html#mix/3"},{"type":"function","title":"Examples - GitHubActions.Mix.mix/3","doc":"iex> mix(:deps, :compile, warnings_as_errors: true)\n    \"mix deps.compile --warnings-as-errors\"","ref":"GitHubActions.Mix.html#mix/3-examples"},{"type":"module","title":"GitHubActions.Project","doc":"A thin wrapper for `Mix.Project` to access the `config`.","ref":"GitHubActions.Project.html"},{"type":"function","title":"GitHubActions.Project.config/0","doc":"","ref":"GitHubActions.Project.html#config/0"},{"type":"type","title":"GitHubActions.Project.default/0","doc":"","ref":"GitHubActions.Project.html#t:default/0"},{"type":"function","title":"GitHubActions.Project.elixir/0","doc":"Returns the Elixir version of the current project.","ref":"GitHubActions.Project.html#elixir/0"},{"type":"function","title":"Examples - GitHubActions.Project.elixir/0","doc":"iex> Project.elixir()\n    \"~> 1.13\"","ref":"GitHubActions.Project.html#elixir/0-examples"},{"type":"function","title":"GitHubActions.Project.fetch/1","doc":"Returns the value for given `keys` from the project config, in a tuple.","ref":"GitHubActions.Project.html#fetch/1"},{"type":"function","title":"Examples - GitHubActions.Project.fetch/1","doc":"iex> Project.fetch(:app)\n    {:ok, :git_hub_actions}\n\n    iex> Project.fetch(:unknown)\n    :error\n\n    iex> Project.fetch([:test_coverage, :tool])\n    {:ok, ExCoveralls}","ref":"GitHubActions.Project.html#fetch/1-examples"},{"type":"function","title":"GitHubActions.Project.fetch!/1","doc":"Returns the value for given `keys` from the project config, raises an error\nif `keys` are not available.","ref":"GitHubActions.Project.html#fetch!/1"},{"type":"function","title":"Examples - GitHubActions.Project.fetch!/1","doc":"iex> Project.fetch!(:app)\n    :git_hub_actions\n\n    iex> Project.fetch!([:test_coverage, :tool])\n    ExCoveralls","ref":"GitHubActions.Project.html#fetch!/1-examples"},{"type":"function","title":"GitHubActions.Project.get/2","doc":"Returns the value for given `keys` from the project config.","ref":"GitHubActions.Project.html#get/2"},{"type":"function","title":"Examples - GitHubActions.Project.get/2","doc":"iex> Project.get(:app)\n    :git_hub_actions\n\n    iex> Project.get(:unknown, 42)\n    42\n\n    iex> Project.get([:test_coverage, :tool])\n    ExCoveralls","ref":"GitHubActions.Project.html#get/2-examples"},{"type":"function","title":"GitHubActions.Project.has_dep?/1","doc":"Returns `true` if the given `dep` is part of the project.","ref":"GitHubActions.Project.html#has_dep?/1"},{"type":"function","title":"Examples - GitHubActions.Project.has_dep?/1","doc":"iex> Project.has_dep?(:credo)\n    true\n\n    iex> Project.has_dep?(:datix)\n    false","ref":"GitHubActions.Project.html#has_dep?/1-examples"},{"type":"type","title":"GitHubActions.Project.key/0","doc":"","ref":"GitHubActions.Project.html#t:key/0"},{"type":"type","title":"GitHubActions.Project.keys/0","doc":"","ref":"GitHubActions.Project.html#t:keys/0"},{"type":"type","title":"GitHubActions.Project.value/0","doc":"","ref":"GitHubActions.Project.html#t:value/0"},{"type":"module","title":"GitHubActions.Sigils","doc":"This module defnies the sigils for `GitHubActions`.","ref":"GitHubActions.Sigils.html"},{"type":"function","title":"GitHubActions.Sigils.sigil_e/2","doc":"Handles the sigile `~e` for GitHub actions expressions.\n\nQuotes the given string as a GitHub expression.","ref":"GitHubActions.Sigils.html#sigil_e/2"},{"type":"function","title":"Examples - GitHubActions.Sigils.sigil_e/2","doc":"iex> ~e[github.sha]\n    \"${{ github.sha }}\"","ref":"GitHubActions.Sigils.html#sigil_e/2-examples"},{"type":"module","title":"GitHubActions.Version","doc":"Functions for parsing and matching versions against requirements.\n\nA version is a string in a specific format or a `GitHubActions.Version` generated after\nparsing via `GitHubActions.Version.parse/1`.\n\nThis module is similar to `Version` except that `minor` and `patch` may be missing\nand `pre` are not supported.\n\nThe Version module can also parse a range of versions.","ref":"GitHubActions.Version.html"},{"type":"module","title":"Examples - GitHubActions.Version","doc":"iex> \"2.0/2\" |> Version.parse!() |> Enum.map(&to_string/1)\n    [\"2.0\", \"2.1\", \"2.2\"]\n\n    iex> \"1/3\" |> Version.parse!() |> Enum.map(&to_string/1)\n    [\"1\", \"2\", \"3\"]","ref":"GitHubActions.Version.html#module-examples"},{"type":"function","title":"GitHubActions.Version.compare/3","doc":"","ref":"GitHubActions.Version.html#compare/3"},{"type":"type","title":"GitHubActions.Version.major/0","doc":"","ref":"GitHubActions.Version.html#t:major/0"},{"type":"function","title":"GitHubActions.Version.major/1","doc":"Returns the mayor version as string.","ref":"GitHubActions.Version.html#major/1"},{"type":"function","title":"Examples - GitHubActions.Version.major/1","doc":"iex> \"1.2.3\" |> Version.parse!() |> Version.major()\n    \"1\"","ref":"GitHubActions.Version.html#major/1-examples"},{"type":"function","title":"GitHubActions.Version.match?/2","doc":"Checks if the given version matches the specification.\n\nReturns `true` if `version` satisfies `requirement`, `false` otherwise.\nRaises a `Version.InvalidRequirementError` exception if `requirement` is not\nparsable, or a `GitHubActions.InvalidVersionError` exception if `version` is\nnot parsable.","ref":"GitHubActions.Version.html#match?/2"},{"type":"function","title":"Examples - GitHubActions.Version.match?/2","doc":"iex> Version.match?(\"2.0\", \"> 1.0.0\")\n    true\n\n    iex> Version.match?(\"2.0\", \"== 1.0.0\")\n    false\n\n    iex> Version.match?(\"2.2.6\", \"~> 2.2.2\")\n    true\n\n    iex> Version.match?(\"2.3\", \"~> 2.2\")\n    true\n\n    iex> Version.match?(\"2\", \"~> 2.1.2\")\n    false\n\n    iex> Version.match?(\"a.b.c\", \"~> 2.1.2\")\n    ** (GitHubActions.InvalidVersionError) invalid version: \"a.b.c\"\n\n    iex> Version.match?(\"2\", \"~~~> 2.1.2\")\n    ** (Version.InvalidRequirementError) invalid requirement: \"~~~> 2.1.2\"","ref":"GitHubActions.Version.html#match?/2-examples"},{"type":"type","title":"GitHubActions.Version.minor/0","doc":"","ref":"GitHubActions.Version.html#t:minor/0"},{"type":"function","title":"GitHubActions.Version.minor/1","doc":"Returns the minor version as string.","ref":"GitHubActions.Version.html#minor/1"},{"type":"function","title":"Examples - GitHubActions.Version.minor/1","doc":"iex> \"1.2.3\" |> Version.parse!() |> Version.minor()\n    \"1.2\"\n\n    iex> \"1\" |> Version.parse!() |> Version.minor()\n    \"1.0\"","ref":"GitHubActions.Version.html#minor/1-examples"},{"type":"function","title":"GitHubActions.Version.parse/1","doc":"Parses a version string into a `GitHubActions.Version` struct.","ref":"GitHubActions.Version.html#parse/1"},{"type":"function","title":"Examples - GitHubActions.Version.parse/1","doc":"iex> {:ok, version} = Version.parse(\"1.2\")\n    iex> version\n    %GitHubActions.Version{major: 1, minor: 2}\n\n    iex> Version.parse(\"1-2\")\n    :error\n\n    iex> {:ok, [v1, v2, v3]} = Version.parse(\"2.2/4\")\n    iex> v1\n    %GitHubActions.Version{major: 2, minor: 2}\n    iex> v2\n    %GitHubActions.Version{major: 2, minor: 3}\n    iex> v3\n    %GitHubActions.Version{major: 2, minor: 4}\n\n    iex> {:ok, version} = Version.parse(\"1.2\")\n    iex> {:ok, version} = Version.parse(version)\n    iex> version\n    %GitHubActions.Version{major: 1, minor: 2}","ref":"GitHubActions.Version.html#parse/1-examples"},{"type":"function","title":"GitHubActions.Version.parse!/1","doc":"Parses a version string into a `GitHubActions.Version` struct.\n\nIf `string` is an invalid version, a GitHubActions.InvalidVersionError is raised.","ref":"GitHubActions.Version.html#parse!/1"},{"type":"function","title":"Examples - GitHubActions.Version.parse!/1","doc":"iex> Version.parse!(\"1\")\n    %GitHubActions.Version{major: 1}\n\n    iex> Version.parse!(\"1.2\")\n    %GitHubActions.Version{major: 1, minor: 2}\n\n    iex> Version.parse!(\"1.2.3\")\n    %GitHubActions.Version{major: 1, minor: 2, patch: 3}\n\n    iex> Version.parse!(\"invalid\")\n    ** (GitHubActions.InvalidVersionError) invalid version: \"invalid\"","ref":"GitHubActions.Version.html#parse!/1-examples"},{"type":"type","title":"GitHubActions.Version.patch/0","doc":"","ref":"GitHubActions.Version.html#t:patch/0"},{"type":"function","title":"GitHubActions.Version.patch/1","doc":"Returns the patch version as string.","ref":"GitHubActions.Version.html#patch/1"},{"type":"function","title":"Examples - GitHubActions.Version.patch/1","doc":"iex> \"1.2.3\" |> Version.parse!() |> Version.patch()\n    \"1.2.3\"\n\n    iex> \"1\" |> Version.parse!() |> Version.patch()\n    \"1.0.0\"","ref":"GitHubActions.Version.html#patch/1-examples"},{"type":"type","title":"GitHubActions.Version.requirement/0","doc":"","ref":"GitHubActions.Version.html#t:requirement/0"},{"type":"type","title":"GitHubActions.Version.t/0","doc":"","ref":"GitHubActions.Version.html#t:t/0"},{"type":"function","title":"GitHubActions.Version.to_requirement/2","doc":"Returns the requiement for the given `version` and `operator`.","ref":"GitHubActions.Version.html#to_requirement/2"},{"type":"function","title":"Examples - GitHubActions.Version.to_requirement/2","doc":"iex> Version.to_requirement(\"1\", \"==\")\n    \"== 1.0.0\"\n    iex> Version.to_requirement(\"1.1\", \">=\")\n    \">= 1.1.0\"\n    iex> Version.to_requirement(\"1.1\", \"~>\")\n    \"~> 1.1\"\n    iex> Version.to_requirement(\"1.1.1\", \"~>\")\n    \"~> 1.1.1\"","ref":"GitHubActions.Version.html#to_requirement/2-examples"},{"type":"type","title":"GitHubActions.Version.version/0","doc":"","ref":"GitHubActions.Version.html#t:version/0"},{"type":"module","title":"GitHubActions.Versions","doc":"Functions to select and filter lists and tables of versions.\n\nThe list of versions can have the following two forms.\n- A simple list:\n  ```elixir\n  [\"1\", \"2.0\", \"2.1\", \"3\", \"3.1\", \"3.1.1\"]\n  ```\n- A table as list of keyword lists with compatible versions:\n  ```elixir\n  [\n    [a: [\"1.0.0\"], b: [\"1.0\", \"1.1\", \"1.2\"]],\n    [a: [\"2.0.0\"], b: [\"1.2\", \"2.0\"]]\n  ]\n  ```","ref":"GitHubActions.Versions.html"},{"type":"function","title":"GitHubActions.Versions.compatible/2","doc":"Returns the compatible versions between `versions1` and `versions2`.","ref":"GitHubActions.Versions.html#compatible/2"},{"type":"function","title":"Examples - GitHubActions.Versions.compatible/2","doc":"iex> versions = Versions.compatible(\n    ...>   elixir: [\"1.9.4\", \"1.10.4\", \"1.11.4\", \"1.12.3\"],\n    ...>   otp: [\"21.3\", \"22.3\", \"23.3\", \"24.0\"]\n    ...> )\n    iex> for [{k1, v1}, {k2, v2}] <- versions do\n    ...>   [{k1, to_string(v1)}, {k2, to_string(v2)}]\n    ...> end\n    [\n      [elixir: \"1.9.4\", otp: \"21.3\"],\n      [elixir: \"1.9.4\", otp: \"22.3\"],\n      [elixir: \"1.10.4\", otp: \"21.3\"],\n      [elixir: \"1.10.4\", otp: \"22.3\"],\n      [elixir: \"1.10.4\", otp: \"23.3\"],\n      [elixir: \"1.11.4\", otp: \"21.3\"],\n      [elixir: \"1.11.4\", otp: \"22.3\"],\n      [elixir: \"1.11.4\", otp: \"23.3\"],\n      [elixir: \"1.11.4\", otp: \"24.0\"],\n      [elixir: \"1.12.3\", otp: \"22.3\"],\n      [elixir: \"1.12.3\", otp: \"23.3\"],\n      [elixir: \"1.12.3\", otp: \"24.0\"]\n    ]","ref":"GitHubActions.Versions.html#compatible/2-examples"},{"type":"function","title":"GitHubActions.Versions.compatible?/2","doc":"Returns `true` if the given `version1` is compatible to `version2`.","ref":"GitHubActions.Versions.html#compatible?/2"},{"type":"function","title":"Examples - GitHubActions.Versions.compatible?/2","doc":"iex> Versions.compatible?(elixir: \"1.12.3\", otp: \"24.0\")\n    true\n\n    iex> Versions.compatible?(elixir: \"1.6.0\", otp: \"24.0\")\n    false\n\n    iex> versions = [\n    ...>   [a: [\"1.0.0\"], b: [\"1.0\", \"1.1\", \"1.2\"]],\n    ...>   [a: [\"2.0.0\"], b: [\"1.2\", \"2.0\"]]\n    ...> ]\n    iex> Versions.compatible?(versions, a: \"1\", b: \"1.2\")\n    true\n    iex> Versions.compatible?(versions, a: \"2\", b: \"1.2\")\n    true\n    iex> Versions.compatible?(versions, a: \"2\", b: \"1\")\n    false\n\n    iex> Versions.compatible?([], a: \"1\", b: \"2\")\n    ** (ArgumentError) compatible?/2 expected a table of versions as first argument, got: []","ref":"GitHubActions.Versions.html#compatible?/2-examples"},{"type":"function","title":"GitHubActions.Versions.compatible_to/3","doc":"Returns the versions of `key` that are compatible_to with `to`.","ref":"GitHubActions.Versions.html#compatible_to/3"},{"type":"function","title":"Examples - GitHubActions.Versions.compatible_to/3","doc":"iex> otp = Versions.compatible_to(:otp, elixir: \"1.6.6\")\n    iex> Enum.map(otp, &to_string/1)\n    [\"19.0\", \"19.1\", \"19.2\", \"19.3\", \"20.0\", \"20.1\", \"20.2\", \"20.3\", \"21.0\",\n     \"21.1\", \"21.2\", \"21.3\"]\n\n    iex> elixir = Versions.compatible_to(:elixir, otp: \"20.3\")\n    iex> Enum.map(elixir, &to_string/1)\n    [\"1.4.5\", \"1.5.0\", \"1.5.1\", \"1.5.2\", \"1.5.3\", \"1.6.0\", \"1.6.1\", \"1.6.2\",\n     \"1.6.3\", \"1.6.4\", \"1.6.5\", \"1.6.6\", \"1.7.0\", \"1.7.1\", \"1.7.2\", \"1.7.3\",\n     \"1.7.4\", \"1.8.0\", \"1.8.1\", \"1.8.2\", \"1.9.0\", \"1.9.1\", \"1.9.2\", \"1.9.3\",\n     \"1.9.4\"]\n\n    iex> :otp |> Versions.compatible_to(elixir: \"1.10.0\") |> Enum.count()\n    8\n\n    iex> :otp |> Versions.compatible_to(elixir: \"1.10.0/4\") |> Enum.count()\n    12\n\n    iex> :otp |> Versions.compatible_to(elixir: [\"1.10.0/4\", \"1.11.0/4\"]) |> Enum.count()\n    16\n\n    iex> Versions.compatible_to([], :otp, elixir: \"1.6.6\")\n    ** (ArgumentError) compatible_to/3 expected a table of versions as first argument, got: []","ref":"GitHubActions.Versions.html#compatible_to/3-examples"},{"type":"function","title":"GitHubActions.Versions.expand/1","doc":"Expands the given `versions`.","ref":"GitHubActions.Versions.html#expand/1"},{"type":"function","title":"Examples - GitHubActions.Versions.expand/1","doc":"iex> versions = Versions.expand([\"1.0/2\"])\n    iex> Enum.map(versions, &to_string/1)\n    [\"1.0\", \"1.1\", \"1.2\"]\n\n    iex> versions = Versions.expand([\n    ...>  [a: [\"1.0/2\"], b: [\"1.0.0/2\"]],\n    ...>  [a: [\"1.1.0/1\"], b: [\"2.0.0/2\"]]\n    ...> ])\n    iex> versions |> Enum.at(1) |> Keyword.get(:a) |> Enum.map(&to_string/1)\n    [\"1.1.0\", \"1.1.1\"]\n    iex> versions |> Enum.at(1) |> Keyword.get(:b) |> Enum.map(&to_string/1)\n    [\"2.0.0\", \"2.0.1\", \"2.0.2\"]\n\n    iex> Versions.expand([:a])\n    ** (ArgumentError) expand/1 expected a list of versions, or table of versions got: [:a]","ref":"GitHubActions.Versions.html#expand/1-examples"},{"type":"function","title":"GitHubActions.Versions.filter/2","doc":"Filters the list of `versions` by the given `requirement`.","ref":"GitHubActions.Versions.html#filter/2"},{"type":"function","title":"Examples - GitHubActions.Versions.filter/2","doc":"iex> versions = [\"1\", \"1.1.0/5\", \"1.2.0/1\", \"1.3\", \"2.0/1\"]\n    iex> Versions.filter(versions, \"~> 1.2\")\n    [\n      %Version{major: 1, minor: 2, patch: 0},\n      %Version{major: 1, minor: 2, patch: 1},\n      %Version{major: 1, minor: 3}\n    ]\n    iex> Versions.filter(versions, \">= 1.3.0\")\n    [\n      %Version{major: 1, minor: 3},\n      %Version{major: 2, minor: 0},\n      %Version{major: 2, minor: 1}\n    ]\n\n    iex> Versions.filter([:b, :a], \"> 1.0.0\")\n    ** (ArgumentError) filter/2 expected a list of versions, got: [:b, :a]\n\n    iex> Versions.filter([\"1\", \"2\", \"3\"], \"> 1\")\n    ** (Version.InvalidRequirementError) invalid requirement: \"> 1\"","ref":"GitHubActions.Versions.html#filter/2-examples"},{"type":"function","title":"GitHubActions.Versions.from_config/0","doc":"Returns the versions from the config.","ref":"GitHubActions.Versions.html#from_config/0"},{"type":"function","title":"GitHubActions.Versions.get/2","doc":"Returns all versions for `key` from a list of compatible versions.\n\nThis function raises a `GitHubActions.InvalidVersionError` for an invalid\nversion.","ref":"GitHubActions.Versions.html#get/2"},{"type":"function","title":"Examples - GitHubActions.Versions.get/2","doc":"iex> versions = [\n    ...>   [a: [\"1.0.0\"], b: [\"1.0\", \"1.1\", \"1.2\"]],\n    ...>   [a: [\"2.0.0\"], b: [\"1.2\", \"2.0\"]]\n    ...> ]\n    iex> versions = Versions.get(versions, :b)\n    iex> hd versions\n    %GitHubActions.Version{major: 1, minor: 0}\n    iex> Enum.map(versions, &to_string/1)\n    [\"1.0\", \"1.1\", \"1.2\", \"2.0\"]\n\n    iex> Versions.get([a: \"1\"], :a)\n    ** (ArgumentError) get/2 expected a table of versions, got: [a: \"1\"]","ref":"GitHubActions.Versions.html#get/2-examples"},{"type":"function","title":"GitHubActions.Versions.incompatible/2","doc":"Returns the incompatible versions between `versions1` and `versions2`.","ref":"GitHubActions.Versions.html#incompatible/2"},{"type":"function","title":"Examples - GitHubActions.Versions.incompatible/2","doc":"iex> versions = Versions.incompatible(\n    ...>   elixir: [\"1.9.4\", \"1.10.4\", \"1.11.4\", \"1.12.3\"],\n    ...>   otp: [\"21.3\", \"22.3\", \"23.3\", \"24.0\"]\n    ...> )\n    iex> for [{k1, v1}, {k2, v2}] <- versions do\n    ...>   [{k1, to_string(v1)}, {k2, to_string(v2)}]\n    ...> end\n    [\n      [elixir: \"1.9.4\", otp: \"23.3\"],\n      [elixir: \"1.9.4\", otp: \"24.0\"],\n      [elixir: \"1.10.4\", otp: \"24.0\"],\n      [elixir: \"1.12.3\", otp: \"21.3\"]\n    ]","ref":"GitHubActions.Versions.html#incompatible/2-examples"},{"type":"function","title":"GitHubActions.Versions.intersection?/2","doc":"Returns true if `versions1` has an intersection with `versions2`.","ref":"GitHubActions.Versions.html#intersection?/2"},{"type":"function","title":"Examples - GitHubActions.Versions.intersection?/2","doc":"iex> Versions.intersection?([\"1.0.0/5\"], [\"1.0.4/7\"])\n    true\n\n    iex> Versions.intersection?([\"1.0.0/5\"], [\"2.0.0/7\"])\n    false\n\n    iex> Versions.intersection?([\"1.0.0/5\"], [:a])\n    ** (ArgumentError) intersection?/2 expected two list of versions, got: [\"1.0.0/5\"], [:a]","ref":"GitHubActions.Versions.html#intersection?/2-examples"},{"type":"type","title":"GitHubActions.Versions.key/0","doc":"","ref":"GitHubActions.Versions.html#t:key/0"},{"type":"function","title":"GitHubActions.Versions.latest/0","doc":"Returns the latest version from the configured versions list.","ref":"GitHubActions.Versions.html#latest/0"},{"type":"function","title":"Examples - GitHubActions.Versions.latest/0","doc":"iex> Config.config(:versions, [\"1.0.0/2\", \"1.1.0/3\"])\n    iex> Versions.latest()\n    %GitHubActions.Version{major: 1, minor: 1, patch: 3}","ref":"GitHubActions.Versions.html#latest/0-examples"},{"type":"function","title":"GitHubActions.Versions.latest/1","doc":"Returns the latest version from the configured `versions` table by the given\n`key` or from the given `versions` list.","ref":"GitHubActions.Versions.html#latest/1"},{"type":"function","title":"Examples - GitHubActions.Versions.latest/1","doc":"iex> Versions.latest([\"1.0.0/2\", \"1.1.0/3\"])\n    %GitHubActions.Version{major: 1, minor: 1, patch: 3}\n\n    iex> Config.config(:versions, [\n    ...>   [a: [\"1.0.0/2\", \"1.1.0/3\"], b: [\"2.0/5\"]],\n    ...>   [a: [\"1.2.0/1\", \"1.3.0/4\"], b: [\"3.0/5\"]]\n    ...> ])\n    iex> Versions.latest(:a)\n    %GitHubActions.Version{major: 1, minor: 3, patch: 4}\n\n    iex> Versions.latest([\"foo\"])\n    ** (GitHubActions.InvalidVersionError) invalid version: \"foo\"\n\n    iex> Versions.latest([a: \"1\"])\n    ** (ArgumentError) latest/1 expected a list or table of versions or a key, got: [a: \"1\"]\n\n    iex> Versions.latest(:elixir)\n    %GitHubActions.Version{major: 1, minor: 18, patch: 1}\n\n    iex> Versions.latest(:otp)\n    %GitHubActions.Version{major: 27, minor: 2}","ref":"GitHubActions.Versions.html#latest/1-examples"},{"type":"function","title":"GitHubActions.Versions.latest/2","doc":"Returns the latest version from a `versions` table by the given `key`.","ref":"GitHubActions.Versions.html#latest/2"},{"type":"function","title":"Examples - GitHubActions.Versions.latest/2","doc":"iex> Versions.latest([\n    ...>   [a: [\"1.0.0/2\"], b: [\"1.0.0/3\"]],\n    ...>   [a: [\"1.1.0/3\"], b: [\"1.1.0/4\"]]\n    ...> ], :a)\n    %GitHubActions.Version{major: 1, minor: 1, patch: 3}\n\n    iex> Versions.latest([a: \"1\"], :a)\n    ** (ArgumentError) latest/1 expected a table of versions,  got: [a: \"1\"]","ref":"GitHubActions.Versions.html#latest/2-examples"},{"type":"function","title":"GitHubActions.Versions.latest_major/0","doc":"Returns the latest major versions from the configured versions list.","ref":"GitHubActions.Versions.html#latest_major/0"},{"type":"function","title":"Examples - GitHubActions.Versions.latest_major/0","doc":"iex> Config.config(:versions, [\"1.0.0/2\", \"1.1.0/4\", \"2.0.0/3\"])\n    iex> Versions.latest_major() |> Enum.map(&to_string/1)\n    [\"1.1.4\", \"2.0.3\"]","ref":"GitHubActions.Versions.html#latest_major/0-examples"},{"type":"function","title":"GitHubActions.Versions.latest_major/1","doc":"Returns the latest major versions from the configured `versions` table by the\ngiven `key` or from the given `versions` list.","ref":"GitHubActions.Versions.html#latest_major/1"},{"type":"function","title":"Examples - GitHubActions.Versions.latest_major/1","doc":"iex> major_versions = Versions.latest_major([\"1.0.0/2\", \"1.1.0/3\", \"2.0.0/2\"])\n    iex> Enum.map(major_versions, &to_string/1)\n    [\"1.1.3\", \"2.0.2\"]\n\n    iex> Config.config(:versions, [\n    ...>   [a: [\"1.0.0/2\", \"1.1.0/3\"], b: [\"2.0/5\"]],\n    ...>   [a: [\"2.2.0/1\", \"2.3.0/4\"], b: [\"3.0/5\"]]\n    ...> ])\n    iex> major_versions = Versions.latest_major(:a)\n    iex> Enum.map(major_versions, &to_string/1)\n    [\"1.1.3\", \"2.3.4\"]\n\n    iex> Versions.latest_major([\"foo\"])\n    ** (GitHubActions.InvalidVersionError) invalid version: \"foo\"\n\n    iex> Versions.latest_major([a: \"1\"])\n    ** (ArgumentError) latest_major/1 expected a list or table of versions or a key, got: [a: \"1\"]\n\n    iex> major_versions = Versions.latest_major(:elixir)\n    iex> Enum.map(major_versions, &to_string/1)\n    [\"1.18.1\"]\n\n    iex> major_versions = Versions.latest_major(:otp)\n    iex> Enum.map(major_versions, &to_string/1)\n    [\"17.5\", \"18.3\", \"19.3\", \"20.3\", \"21.3\", \"22.3\", \"23.3\", \"24.3\", \"25.3\", \"26.2\", \"27.2\"]","ref":"GitHubActions.Versions.html#latest_major/1-examples"},{"type":"function","title":"GitHubActions.Versions.latest_major/2","doc":"Returns the latest major versions from a `versions` table by the given `key`.","ref":"GitHubActions.Versions.html#latest_major/2"},{"type":"function","title":"Examples - GitHubActions.Versions.latest_major/2","doc":"iex> major_versions = Versions.latest_major([\n    ...>   [a: [\"1.0.0/2\"], b: [\"1.0.0/3\"]],\n    ...>   [a: [\"2.0.0/3\"], b: [\"2.0.0/4\"]]\n    ...> ], :a)\n    iex> Enum.map(major_versions, &to_string/1)\n    [\"1.0.2\", \"2.0.3\"]\n\n    iex> Versions.latest_major([a: \"1\"], :a)\n    ** (ArgumentError) latest_major/1 expected a table of versions,  got: [a: \"1\"]","ref":"GitHubActions.Versions.html#latest_major/2-examples"},{"type":"function","title":"GitHubActions.Versions.latest_minor/0","doc":"Returns the latest minor versions from the configured versions list.","ref":"GitHubActions.Versions.html#latest_minor/0"},{"type":"function","title":"Examples - GitHubActions.Versions.latest_minor/0","doc":"iex> Config.config(:versions, [\"1.0.0/2\", \"1.1.0/4\", \"2.0.0/3\"])\n    iex> Versions.latest_minor() |> Enum.map(&to_string/1)\n    [\"1.0.2\", \"1.1.4\", \"2.0.3\"]","ref":"GitHubActions.Versions.html#latest_minor/0-examples"},{"type":"function","title":"GitHubActions.Versions.latest_minor/1","doc":"Returns the latest minor versions from the configured `versions` table by the\ngiven `key` or from the given `versions` list.","ref":"GitHubActions.Versions.html#latest_minor/1"},{"type":"function","title":"Examples - GitHubActions.Versions.latest_minor/1","doc":"iex> minor_versions = Versions.latest_minor([\"1.0.0/2\", \"1.1.0/3\"])\n    iex> Enum.map(minor_versions, &to_string/1)\n    [\"1.0.2\", \"1.1.3\"]\n\n    iex> Config.config(:versions, [\n    ...>   [a: [\"1.0.0/2\", \"1.1.0/3\"], b: [\"2.0/5\"]],\n    ...>   [a: [\"1.2.0/1\", \"1.3.0/4\"], b: [\"3.0/5\"]]\n    ...> ])\n    iex> minor_versions = Versions.latest_minor(:a)\n    iex> Enum.map(minor_versions, &to_string/1)\n    [\"1.0.2\", \"1.1.3\", \"1.2.1\", \"1.3.4\"]\n\n    iex> Versions.latest_minor([\"foo\"])\n    ** (GitHubActions.InvalidVersionError) invalid version: \"foo\"\n\n    iex> Versions.latest_minor([a: \"1\"])\n    ** (ArgumentError) latest_minor/1 expected a list or table of versions or a key, got: [a: \"1\"]\n\n    iex> minor_versions = Versions.latest_minor(:elixir)\n    iex> Enum.map(minor_versions, &to_string/1)\n    [\"1.0.5\", \"1.1.1\", \"1.2.6\", \"1.3.4\", \"1.4.5\", \"1.5.3\", \"1.6.6\", \"1.7.4\",\n     \"1.8.2\", \"1.9.4\", \"1.10.4\", \"1.11.4\", \"1.12.3\", \"1.13.4\", \"1.14.5\",\n     \"1.15.8\", \"1.16.3\", \"1.17.3\", \"1.18.1\"]\n\n    iex> minor_versions = Versions.latest_minor(:otp)\n    iex> Enum.map(minor_versions, &to_string/1)\n    [\"17.0\", \"17.1\", \"17.2\", \"17.3\", \"17.4\", \"17.5\", \"18.0\", \"18.1\", \"18.2\",\n     \"18.3\", \"19.0\", \"19.1\", \"19.2\", \"19.3\", \"20.0\", \"20.1\", \"20.2\", \"20.3\",\n     \"21.0\", \"21.1\", \"21.2\", \"21.3\", \"22.0\", \"22.1\", \"22.2\", \"22.3\", \"23.0\",\n     \"23.1\", \"23.2\", \"23.3\", \"24.0\", \"24.1\", \"24.2\", \"24.3\", \"25.0\", \"25.1\",\n     \"25.2\", \"25.3\", \"26.0\", \"26.1\", \"26.2\", \"27.0\", \"27.1\", \"27.2\"]","ref":"GitHubActions.Versions.html#latest_minor/1-examples"},{"type":"function","title":"GitHubActions.Versions.latest_minor/2","doc":"Returns the latest minor versions from a `versions` table by the given `key`.","ref":"GitHubActions.Versions.html#latest_minor/2"},{"type":"function","title":"Examples - GitHubActions.Versions.latest_minor/2","doc":"iex> minor_versions = Versions.latest_minor([\n    ...>   [a: [\"1.0.0/2\"], b: [\"1.0.0/3\"]],\n    ...>   [a: [\"1.1.0/3\"], b: [\"1.1.0/4\"]]\n    ...> ], :a)\n    iex> Enum.map(minor_versions, &to_string/1)\n    [\"1.0.2\", \"1.1.3\"]\n\n    iex> Versions.latest_minor([a: \"1\"], :a)\n    ** (ArgumentError) latest_minor/1 expected a table of versions,  got: [a: \"1\"]","ref":"GitHubActions.Versions.html#latest_minor/2-examples"},{"type":"function","title":"GitHubActions.Versions.matrix/2","doc":"Returns the versions matrix for the given requirements.","ref":"GitHubActions.Versions.html#matrix/2"},{"type":"function","title":"Options - GitHubActions.Versions.matrix/2","doc":"- `:mode` - accepts `:include` or `:exclude`. Defaults to `:exclude`.\n\n    With `:exclude` a keyword list with all versions for the requirements and\n    a table with the incompatible versions is returned. The table of\n    incompatible versions can be found under the `:exclude` key.\n\n    With `:include` only the compatible versions are returned. The table of\n    compatible versions can be found under the `:include` key.","ref":"GitHubActions.Versions.html#matrix/2-options"},{"type":"function","title":"Examples - GitHubActions.Versions.matrix/2","doc":"iex> matrix = Versions.matrix(elixir: \">= 1.12.0\", otp: \">= 22.0.0\")\n    iex> Enum.map(matrix[:elixir], &to_string/1)\n    [\"1.12.3\", \"1.13.4\", \"1.14.5\", \"1.15.8\", \"1.16.3\", \"1.17.3\", \"1.18.1\"]\n    iex> Enum.map(matrix[:otp], &to_string/1)\n    [\"22.3\", \"23.3\", \"24.3\", \"25.3\", \"26.2\", \"27.2\"]\n    iex> for [{k1, v1}, {k2, v2}] <- matrix[:exclude] do\n    ...>   [{k1, to_string(v1)}, {k2, to_string(v2)}]\n    ...> end\n    [\n      [elixir: \"1.12.3\", otp: \"25.3\"],\n      [elixir: \"1.12.3\", otp: \"26.2\"],\n      [elixir: \"1.12.3\", otp: \"27.2\"],\n      [elixir: \"1.13.4\", otp: \"26.2\"],\n      [elixir: \"1.13.4\", otp: \"27.2\"],\n      [elixir: \"1.14.5\", otp: \"22.3\"],\n      [elixir: \"1.14.5\", otp: \"27.2\"],\n      [elixir: \"1.15.8\", otp: \"22.3\"],\n      [elixir: \"1.15.8\", otp: \"23.3\"],\n      [elixir: \"1.15.8\", otp: \"27.2\"],\n      [elixir: \"1.16.3\", otp: \"22.3\"],\n      [elixir: \"1.16.3\", otp: \"23.3\"],\n      [elixir: \"1.16.3\", otp: \"27.2\"],\n      [elixir: \"1.17.3\", otp: \"22.3\"],\n      [elixir: \"1.17.3\", otp: \"23.3\"],\n      [elixir: \"1.17.3\", otp: \"24.3\"],\n      [elixir: \"1.18.1\", otp: \"22.3\"],\n      [elixir: \"1.18.1\", otp: \"23.3\"],\n      [elixir: \"1.18.1\", otp: \"24.3\"]\n    ]\n\n    iex> matrix = Versions.matrix(\n    ...>   elixir: \">= 1.15.0 and < 1.19.0\",\n    ...>   otp: \">= 22.0.0\",\n    ...>   mode: :include\n    ...> )\n    iex> for [{k1, v1}, {k2, v2}] <- matrix[:include] do\n    ...>   [{k1, to_string(v1)}, {k2, to_string(v2)}]\n    ...> end\n    [\n      [elixir: \"1.15.8\", otp: \"24.3\"],\n      [elixir: \"1.15.8\", otp: \"25.3\"],\n      [elixir: \"1.15.8\", otp: \"26.2\"],\n      [elixir: \"1.16.3\", otp: \"24.3\"],\n      [elixir: \"1.16.3\", otp: \"25.3\"],\n      [elixir: \"1.16.3\", otp: \"26.2\"],\n      [elixir: \"1.17.3\", otp: \"25.3\"],\n      [elixir: \"1.17.3\", otp: \"26.2\"],\n      [elixir: \"1.17.3\", otp: \"27.2\"],\n      [elixir: \"1.18.1\", otp: \"25.3\"],\n      [elixir: \"1.18.1\", otp: \"26.2\"],\n      [elixir: \"1.18.1\", otp: \"27.2\"]\n    ]\n\n    iex> Versions.matrix([], elixir: \">= 1.9.0\", otp: \">= 22.0.0\")\n    ** (ArgumentError) matrix/1 expected a table of versions as first argument, got: []","ref":"GitHubActions.Versions.html#matrix/2-examples"},{"type":"function","title":"GitHubActions.Versions.member?/2","doc":"Returns true if `versions` contains the given `version`.","ref":"GitHubActions.Versions.html#member?/2"},{"type":"function","title":"Examples - GitHubActions.Versions.member?/2","doc":"iex> versions = [\"1.0.0\", \"1.1.0\", \"1.1.1\"]\n    iex> Versions.member?(versions, \"1.1\")\n    true\n    iex> Versions.member?(versions, \"1.0.1\")\n    false\n\n    iex> Versions.member?([a: \"1\"], \"1.0.0\")\n    ** (ArgumentError) member?/2 expected a list of versions, got: [a: \"1\"]","ref":"GitHubActions.Versions.html#member?/2-examples"},{"type":"function","title":"GitHubActions.Versions.minimize/1","doc":"Minimizes the given versions table.\n\nReturns the minimised table where each version of the table is present at least\nonce in the result. This means that not all possible combinations are present\nin the result.","ref":"GitHubActions.Versions.html#minimize/1"},{"type":"function","title":"Examples - GitHubActions.Versions.minimize/1","doc":"iex> versions = [\n    ...>   [\n    ...>     elixir: %GitHubActions.Version{major: 1, minor: 16, patch: 3},\n    ...>     otp: %GitHubActions.Version{major: 24, minor: 3}\n    ...>   ],\n    ...>   [\n    ...>     elixir: %GitHubActions.Version{major: 1, minor: 16, patch: 3},\n    ...>     otp: %GitHubActions.Version{major: 25, minor: 3}\n    ...>   ],\n    ...>   [\n    ...>     elixir: %GitHubActions.Version{major: 1, minor: 16, patch: 3},\n    ...>     otp: %GitHubActions.Version{major: 26, minor: 2}\n    ...>   ],\n    ...>   [\n    ...>     elixir: %GitHubActions.Version{major: 1, minor: 17, patch: 3},\n    ...>     otp: %GitHubActions.Version{major: 25, minor: 3}\n    ...>   ],\n    ...>   [\n    ...>     elixir: %GitHubActions.Version{major: 1, minor: 17, patch: 3},\n    ...>     otp: %GitHubActions.Version{major: 26, minor: 2}\n    ...>   ],\n    ...>   [\n    ...>     elixir: %GitHubActions.Version{major: 1, minor: 17, patch: 3},\n    ...>     otp: %GitHubActions.Version{major: 27, minor: 2}\n    ...>   ],\n    ...>   [\n    ...>     elixir: %GitHubActions.Version{major: 1, minor: 18, patch: 0},\n    ...>     otp: %GitHubActions.Version{major: 25, minor: 3}\n    ...>   ],\n    ...>   [\n    ...>     elixir: %GitHubActions.Version{major: 1, minor: 18, patch: 0},\n    ...>     otp: %GitHubActions.Version{major: 26, minor: 2}\n    ...>   ],\n    ...>   [\n    ...>     elixir: %GitHubActions.Version{major: 1, minor: 18, patch: 0},\n    ...>     otp: %GitHubActions.Version{major: 27, minor: 2}\n    ...>   ]\n    ...> ]\n    iex> Versions.minimize(versions)\n    [\n      [\n        elixir: %GitHubActions.Version{major: 1, minor: 18, patch: 0},\n        otp: %GitHubActions.Version{major: 27, minor: 2}\n      ],\n      [\n        elixir: %GitHubActions.Version{major: 1, minor: 18, patch: 0},\n        otp: %GitHubActions.Version{major: 26, minor: 2}\n      ],\n      [\n        elixir: %GitHubActions.Version{major: 1, minor: 18, patch: 0},\n        otp: %GitHubActions.Version{major: 25, minor: 3}\n      ],\n      [\n        elixir: %GitHubActions.Version{major: 1, minor: 17, patch: 3},\n        otp: %GitHubActions.Version{major: 25, minor: 3}\n      ],\n      [\n        elixir: %GitHubActions.Version{major: 1, minor: 16, patch: 3},\n        otp: %GitHubActions.Version{major: 24, minor: 3}\n      ]\n    ]","ref":"GitHubActions.Versions.html#minimize/1-examples"},{"type":"function","title":"GitHubActions.Versions.sort/1","doc":"Sorts the given `versions`.","ref":"GitHubActions.Versions.html#sort/1"},{"type":"function","title":"Examples - GitHubActions.Versions.sort/1","doc":"iex> versions = [\"1.1\", \"11.1\", \"1.0\", \"2.1\", \"2.0.1\", \"2.0.0\"]\n    iex> versions = Versions.sort(versions)\n    iex> Enum.map(versions, &to_string/1)\n    [\"1.0\", \"1.1\", \"2.0.0\", \"2.0.1\", \"2.1\", \"11.1\"]\n\n    iex> Versions.sort([a: [\"1\", \"2\"]])\n    ** (ArgumentError) sort/2 expected a list or table of versions, got: [a: [\"1\", \"2\"]]","ref":"GitHubActions.Versions.html#sort/1-examples"},{"type":"function","title":"GitHubActions.Versions.uniq/1","doc":"Removes all duplicated versions.","ref":"GitHubActions.Versions.html#uniq/1"},{"type":"function","title":"Examples - GitHubActions.Versions.uniq/1","doc":"iex> versions = Versions.expand([\"1.0.0/4\", \"1.0.2/5\"])\n    iex> versions |> Versions.uniq() |> Enum.map(&to_string/1)\n    [\"1.0.0\", \"1.0.1\", \"1.0.2\", \"1.0.3\", \"1.0.4\", \"1.0.5\"]\n\n    iex> Versions.uniq([:a])\n    ** (ArgumentError) uniq/1 expected a list or table of versions, got: [:a]","ref":"GitHubActions.Versions.html#uniq/1-examples"},{"type":"type","title":"GitHubActions.Versions.versions/0","doc":"","ref":"GitHubActions.Versions.html#t:versions/0"},{"type":"type","title":"GitHubActions.Versions.versions_list/0","doc":"","ref":"GitHubActions.Versions.html#t:versions_list/0"},{"type":"type","title":"GitHubActions.Versions.versions_table/0","doc":"","ref":"GitHubActions.Versions.html#t:versions_table/0"},{"type":"module","title":"GitHubActions.Workflow","doc":"The `GitHubActions.Workflow` is used to create a GitHub actions workflow.\n\n```elixir\ndefmodule Minimal do\n  use GitHubActions.Workflow\n\n  def workflow do\n    [\n      name: \"CI\"\n    ]\n  end\nend\n```\n\nThe workflow module must define the `workflow/0` function. This function\nreturns a nested data structure that will be translated in a yml-file.\n\nThe line `use GitHubActions.Workflow` imports `GitHubActions.Workflow`,\n`GitHubActions.Mix` and `GitHubActions.Sigils` and adds the aliases\n`GitHubActions.Config`, `GitHubActions.Project` and `GitHubActions.Versions`.\n\nList entries with the value `:skip` are not taken over.\n\nKey-value pairs with a value of `:skip` are also not part of the resulting\ndata structure.\n\nWith :skip, you can handle optional parts in a workflow script.\n\n```elixir\ndefmodule Simple do\n  use GitHubActions.Workflow\n\n  def workflow do\n    [\n      name: \"CI\",\n      jobs: [\n        linux: linux(),\n        os2: os2()\n      ]\n    ]\n  end\n\n  defp linux do\n    job(:linux,\n      name: \"Test on #{Config.fetch!([:linux, :name])}\",\n      runs_on: Config.fetch!([:linux, :runs_on])\n    )\n  end\n\n  defp os2 do\n    job(:linux,\n      name: \"Test on #{Config.fetch!([:os2, :name])}\",\n      runs_on: Config.fetch!([:os2, :runs_on])\n    )\n  end\n\n  defp job(os, cofig) do\n    case :jobs |> Config.get([]) |> Enum.member?(os) do\n      true -> config\n      false -> :skip\n    end\n  end\nend\n```\n\nIt is also possible to add steps when a dependency is available in the current\nproject.\n\n```elixir\ndefmodule Simple do\n  use GitHubActions.Workflow\n\n  def workflow do\n    [\n      name: \"CI\",\n      jobs: [linux: linux()]\n    ]\n  end\n\n  defp linux do\n    name: \"Test on #{Config.fetch!([:linux, :name])}\",\n    runs_on: Config.fetch!([:linux, :runs_on])\n    steps: [\n      checkout(),\n      check_code_format(),\n      lint_code()\n    ]\n  end\n\n  defp checkout do\n    [\n      name: \"Checkout\",\n      uses: \"actions/checkout@v4\"\n    ]\n  end\n\n  defp lint_code do\n    case Project.has_dep?(:credo) do\n      false ->\n        :skip\n\n      true ->\n        [\n          name: \"Lint code\",\n          run: mix(:credo, strict: true, env: :test)\n        ]\n    end\n  end\n\n  defp check_code_format do\n    case Config.get(:check_code_format, true) do\n      false ->\n        :skip\n\n      true ->\n        [\n          name: \"Check code format\",\n          run: mix(:format, check_formatted: true, env: :test)\n        ]\n    end\n  end\nend\n```","ref":"GitHubActions.Workflow.html"},{"type":"function","title":"GitHubActions.Workflow.eval/1","doc":"Evaluates a workflow script and returns the workflow data structure.","ref":"GitHubActions.Workflow.html#eval/1"},{"type":"task","title":"mix gha","doc":"Creates a GitHub actions file.\n\nSee [Usage](/git_hub_actions/usage.html) and\n[Defaults](/git_hub_actions/defaults.html) for more information.","ref":"Mix.Tasks.Gha.html"},{"type":"task","title":"Command line options - mix gha","doc":"- `--config`, `-c` - specifies the config file\n- `--elixir`, `-e` - puts the given Elixir verion to the config\n- `--output`, `-o` - specifites the output file, defaults to\n  `.github/workflows/ci.yml`\n- `--workflow`, `-w` - specifies the workflow script","ref":"Mix.Tasks.Gha.html#module-command-line-options"},{"type":"task","title":"mix gha.config","doc":"Creates a `GitHubActions` directory with config and default workflow.\n\nThe config file gets the name `config.exs` and the default workflow gets the\nname `defaults.exs`.","ref":"Mix.Tasks.Gha.Config.html"},{"type":"task","title":"Command line options - mix gha.config","doc":"- `--gen-global` - creates `~/.gha`\n- `--gen-local` - creates `.gha`","ref":"Mix.Tasks.Gha.Config.html#module-command-line-options"},{"type":"exception","title":"GitHubActions.Error","doc":"","ref":"GitHubActions.Error.html"},{"type":"exception","title":"GitHubActions.InvalidVersionError","doc":"","ref":"GitHubActions.InvalidVersionError.html"},{"type":"extras","title":"Usage","doc":"# Usage\n\n`GitHubActions` is a little tool to write GitHub actions in Elixir. This lib\nis an early beta and is currently experimental.","ref":"usage.html"},{"type":"extras","title":"Install - Usage","doc":"`GitHubActions` can be installed as an archive.\n\n```shell\n$> mix archive.install hex git_hub_actions\n```\nOr, as a dependency.\n\n``` elixir\ndef deps do\n  [\n    {:git_hub_actions, \"~> 0.1\", only: :dev}\n  ]\nend\n```","ref":"usage.html#install"},{"type":"extras","title":"Create a workflow yml - Usage","doc":"`GitHubActions` comes with some default settings to create a workflow yml. You\ncan run `mix gha` in a project root directory to create\n`.github/workflows/ci.yml`.\n\n```shell\n$> mix gha\n* creating .github/workflows/ci.yml\n```\n\nSee the [`Defaults`](#defaults) section for information on the defaults.","ref":"usage.html#create-a-workflow-yml"},{"type":"extras","title":"Custom workflow and config - Usage","doc":"See `GitHubActions.Workflow` for how to write a workflow script.\n\nThe `mix` task `gha` comes with the options `--workflow` and `--config` to use\ncustom scripts. The config will be merged into the default config.\n\nIt is also possible to setup a `./.gha` directory in your home directory or in the\nproject root directory. The `mix` task `gha.config` with the options\n`--gen-global` and `--gen-local` will copy the defaults to the related location.\n\nThe configuration will be read from `priv/config.exs` and afterward updated\nby `~/.gha/config.exs` and then by `./.gha/config.exs`.\n\n`GitHubActions` will search the workflow script in the order `./.gha/default.exs`,\n`~/.gha/default.exs` and `priv/default.exs`. The name of the default script can\nbe changed in the configuration under `input: [default: \"my_workflow.exs\"]`.","ref":"usage.html#custom-workflow-and-config"},{"type":"extras","title":"Defaults - Usage","doc":"The defaults create a workflow file that runs on `ubuntu-20.04`. The matrix is\ncreated with the setting of `elixir` from the relevant project and the `OTP`\nversions `> 21.0.0`.\n\nThe workflow file (e.g. `.github/workflows/ci.yml`) is created by a workflow\nscript. The default workflow script is in \n[`priv/default.exs`](https://github.com/hrzndhrn/git_hub_actions/blob/main/priv/default.exs).\n\nThe workflow script uses data from the config. The default config is in\n[`priv/config.exs`](https://github.com/hrzndhrn/git_hub_actions/blob/main/priv/config.exs).\n\nThe `linux` job gets the following steps:\n- `checkout`\n- `setup_elixir`, using `erlef/setup-elixir@v1`\n- `restore(:deps)`, can be suppressed by config\n- `restore(:_build)`, can be suppressed by config\n- `restore(:dialyxir)`, when `:dialyxir` is part of the dependencies,\n  can be suppressed by config\n- `get_deps`\n- `compile_deps`\n- `compile`, with `--warnings-as-errors`\n- `check_code_format`, can be suppressed by config, executes only for the latest\n   Elixir/OTP version\n- `lint_code`, when `:credo` is part of the dependencies, executes only for the\n  latest Elixir/OTP version\n- `run_tests`\n- `dialyxir`, when `:dialyxir` is part of the dependencies\n\nThe workflow script also contains jobs for `macOS` and `Windows`.  To activate\nthese jobs, set `config :jobs, [:linux, :macos, :windows]` in the config.  The\njobs for `macOS` and `Windows` use just the latest Elixir/OTP version.","ref":"usage.html#defaults"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}